@@ -110,9 +110,16 @@ mkdir 'out' 'inst' || exit 1
 		rm -f "${BUILDDIR}/kit.rc"
 	fi
 
+	# Cleanup
+	rm -f kit kit.exe tclsh tclsh.exe
+
 	# Determine if target is KitDLL or KitSH
 	if [ "${KITTARGET}" = "kitdll" ]; then
-		CONFIGUREEXTRA="${CONFIGUREEXTRA} --enable-kitdll"
+		if [ "${KITCREATOR_STATIC_KITDLL}" = '1' ]; then
+			CONFIGUREEXTRA="${CONFIGUREEXTRA} --enable-kitdll=static"
+		else
+			CONFIGUREEXTRA="${CONFIGUREEXTRA} --enable-kitdll"
+		fi
 	fi
 
 	# Compile Kit
@@ -131,7 +138,7 @@ mkdir 'out' 'inst' || exit 1
 
 	# Strip the kit of all symbols, if possible
 	if ! echo " ${CONFIGUREEXTRA} " | grep ' --enable-symbols ' >/dev/null; then
-		"${STRIP:-strip}" kit >/dev/null 2>/dev/null
+		"${STRIP:-strip}" kit kit.exe >/dev/null 2>/dev/null
 		"${STRIP:-strip}" -g libtclkit* >/dev/null 2>/dev/null
 	fi
 
@@ -165,25 +172,33 @@ mkdir 'out' 'inst' || exit 1
 				continue
 			fi
 
-			if echo "${chkkittarget}" | egrep '\.(lib|def|a)$'; then
+			if echo "${chkkittarget}" | egrep '\..*\.(lib|def|a)$'; then
 				continue
 			fi
 
-			KITTARGET_NAME="${chkkittarget}"
+			KITTARGET_NAME="./${chkkittarget}"
 
 			break
 		done
 
 		## Also create an executable named "kit" so that we can run it later
 		${MAKE:-make} tclsh
-		mv tclsh kit
+		if [ -f "tclsh.exe" ]; then
+			mv tclsh.exe kit.exe
+		else
+			mv tclsh kit
+		fi
 	else
 		## The executable is always named "kit"
-		KITTARGET_NAME='kit'
+		if [ -f 'kit.exe' ]; then
+			KITTARGET_NAME='./kit.exe'
+		else
+			KITTARGET_NAME='./kit'
+		fi
 	fi
 	export KITTARGET_NAME
 
-	if [ "x${KITTARGET_NAME}" = 'x__error__' ]; then
+	if [ "${KITTARGET_NAME}" = '__error__' ]; then
 		echo "Failed to locate kit target!" >&2
 
 		exit 1
@@ -195,31 +210,34 @@ mkdir 'out' 'inst' || exit 1
 	if echo 'exit 0' | "${TCLKIT}" >/dev/null 2>/dev/null; then
 		## Install using existing Tclkit
 		### Call installer
-		echo "Running: \"${TCLKIT}\" installvfs.tcl \"${KITTARGET_NAME}\" starpack.vfs \"${ENABLECOMPRESSION}\""
-		"${TCLKIT}" installvfs.tcl "${KITTARGET_NAME}" starpack.vfs "${ENABLECOMPRESSION}" || exit 1
-	elif echo 'exit 0' | ./kit >/dev/null 2>/dev/null; then
-		## Bootstrap (cannot cross-compile)
-		### Call installer
-		cp kit runkit
-		echo "set argv [list {${KITTARGET_NAME}} starpack.vfs {${ENABLECOMPRESSION}}]" > setup.tcl
-		echo 'if {[catch { clock seconds }]} { proc clock args { return 0 } }' >> setup.tcl
-		echo 'source installvfs.tcl' >> setup.tcl
-
-		echo 'Running: echo | ./runkit setup.tcl'
-		echo | ./runkit setup.tcl || exit 1
+		echo "Running: \"${TCLKIT}\" installvfs.tcl \"${KITTARGET_NAME}\" starpack.vfs \"${ENABLECOMPRESSION}\" \"${KITTARGET_NAME}.new\""
+		"${TCLKIT}" installvfs.tcl "${KITTARGET_NAME}" starpack.vfs "${ENABLECOMPRESSION}" "${KITTARGET_NAME}.new" || exit 1
 	else
-		## Install using Tclsh, which may work if we're not using Metakit
-		### Call installer
-		echo "Running: \"${TCLSH_NATIVE}\" installvfs.tcl \"${KITTARGET_NAME}\" starpack.vfs \"${ENABLECOMPRESSION}\""
-		"${TCLSH_NATIVE}" installvfs.tcl "${KITTARGET_NAME}" starpack.vfs "${ENABLECOMPRESSION}" || exit 1
-		
+		if echo 'exit 0' | "${KITTARGET_NAME}" >/dev/null 2>/dev/null; then
+			## Bootstrap (cannot cross-compile)
+			### Call installer
+			echo "set argv [list {${KITTARGET_NAME}} starpack.vfs {${ENABLECOMPRESSION}} {${KITTARGET_NAME}.new}]" > setup.tcl
+			echo 'if {[catch { clock seconds }]} { proc clock args { return 0 } }' >> setup.tcl
+			echo 'source installvfs.tcl' >> setup.tcl
+
+			echo 'Running: echo | \"${KITTARGET_NAME}\" setup.tcl'
+			echo | "${KITTARGET_NAME}" setup.tcl || exit 1
+		else
+			## Install using Tclsh, which may work if we're not using Metakit
+			### Call installer
+			echo "Running: \"${TCLSH_NATIVE}\" installvfs.tcl \"${KITTARGET_NAME}\" starpack.vfs \"${ENABLECOMPRESSION}\" \"${KITTARGET_NAME}.new\""
+			"${TCLSH_NATIVE}" installvfs.tcl "${KITTARGET_NAME}" starpack.vfs "${ENABLECOMPRESSION}" "${KITTARGET_NAME}.new" || exit 1
+		fi
 	fi
 
+	cp "${KITTARGET_NAME}.new" "${KITTARGET_NAME}"
+	rm -f "${KITTARGET_NAME}.new"
+
 	# Cleanup
 	if [ "${KITTARGET}" = "kitdll" ]; then
 		## Remove built interpreters if we are building KitDLL --
 		## they're just tiny stubs anyway
-		rm -f kit runkit
+		rm -f kit kit.exe
 	fi
 
 	exit 0
