@@ -14,6 +14,7 @@ fi
 ZLIBVERS="1.2.8"
 SRC="src/zlib-${ZLIBVERS}.tar.gz"
 SRCURL="http://sourceforge.net/projects/libpng/files/zlib/${ZLIBVERS}/zlib-${ZLIBVERS}.tar.gz/download"
+SRCHASH='36658cb768a54c1d4dec43c3116c27ed893e88b02ecfcb44f2166f9c0b7f2a0d'
 BUILDDIR="$(pwd)/build/zlib-${ZLIBVERS}"
 OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
@@ -33,9 +34,7 @@ if [ ! -f "${SRC}" ]; then
 	mkdir 'src' >/dev/null 2>/dev/null
 
 	if [ ! -d 'buildsrc' ]; then
-		rm -f "${SRC}.tmp"
-		wget -O "${SRC}.tmp" "${SRCURL}" || exit 1
-		mv "${SRC}.tmp" "${SRC}"
+		download "${SRCURL}" "${SRC}" "${SRCHASH}" || exit 1
 	fi
 fi
 
@@ -44,28 +43,43 @@ fi
 
 	if [ ! -d '../buildsrc' ]; then
 		gzip -dc "../${SRC}" | tar -xf -
-	else    
+	else
 		cp -rp ../buildsrc/* './'
 	fi
 
 	cd "${BUILDDIR}" || exit 1
 
-	# If we are building for KitDLL, compile with '-fPIC'
-	if [ "${KITTARGET}" = "kitdll" ]; then
-		CFLAGS="${CFLAGS} -fPIC"
-		export CFLAGS
-	fi
+	case $(uname -s 2> /dev/null) in
+		MINGW* | mingw*)
+			# use win32/Makefile.gcc instead.
+			echo "Running: cp win32/Makefile.gcc Makefile"
+			cp win32/Makefile.gcc Makefile
 
-	# We don't pass CONFIGUREEXTRA here, since this isn't a GNU autoconf
-	# script and will puke
-	echo "Running: ./configure --prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\" --static"
-	./configure --prefix="${INSTDIR}" --libdir="${INSTDIR}/lib" --static
+			echo "Running: ${MAKE:-make}"
+			${MAKE:-make} || exit 1
 
-	echo "Running: ${MAKE:-make}"
-	${MAKE:-make} || exit 1
+			echo "Running: BINARY_PATH=${INSTDIR}/bin INCLUDE_PATH=${INSTDIR}/include LIBRARY_PATH=${INSTDIR}/lib ${MAKE:-make} install"
+			BINARY_PATH=${INSTDIR}/bin INCLUDE_PATH=${INSTDIR}/include LIBRARY_PATH=${INSTDIR}/lib ${MAKE:-make} install
+			;;
+		*)
+			# If we are building for KitDLL, compile with '-fPIC'
+			if [ "${KITTARGET}" = "kitdll" ]; then
+				CFLAGS="${CFLAGS} -fPIC"
+				export CFLAGS
+			fi
 
-	echo "Running: ${MAKE:-make} install"
-	${MAKE:-make} install
+			# We don't pass CONFIGUREEXTRA here, since this isn't a GNU autoconf
+			# script and will puke
+			echo "Running: ./configure --prefix=\"${INSTDIR}\" --libdir=\"${INSTDIR}/lib\" --static"
+			./configure --prefix="${INSTDIR}" --libdir="${INSTDIR}/lib" --static
+
+			echo "Running: ${MAKE:-make}"
+			${MAKE:-make} || exit 1
+
+			echo "Running: ${MAKE:-make} install"
+			${MAKE:-make} install
+			;;
+	esac
 
 	# We don't really care too much about failure in zlib
 	exit 0
